import numpy as np

def gauss_seidel_solver(A, b, initial_guess=None, tol=1e-6, max_iter=1000):
    """
    Resuelve el sistema Ax = b usando el método de Gauss-Seidel.
    
    Parámetros:
        A: Matriz de coeficientes (numpy array 2D).
        b: Vector de términos independientes (numpy array 1D).
        initial_guess: Valores iniciales para las variables (opcional).
        tol: Tolerancia para la convergencia (por defecto 1e-6).
        max_iter: Máximo número de iteraciones (por defecto 1000).
    
    Retorna:
        x: Solución del sistema (numpy array 1D).
        iterations: Número de iteraciones realizadas.
    """
    n = len(b)
    x = initial_guess.copy() if initial_guess is not None else np.zeros(n)
    
    for iterations in range(1, max_iter + 1):
        x_old = x.copy()
        
        for i in range(n):
            sum_ax = np.dot(A[i, :i], x[:i]) + np.dot(A[i, i + 1:], x_old[i + 1:])
            x[i] = (b[i] - sum_ax) / A[i, i]
        
        # Criterio de convergencia
        if np.linalg.norm(x - x_old, ord=np.inf) < tol:
            break
    
    return x, iterations


import numpy as np

def gauss_jordan_solver(matrix, tol=1e-10):
    
    if matrix is None or not isinstance(matrix, np.ndarray):
        raise ValueError("El argumento 'matrix' no puede ser nulo.")
    
    m = matrix.astype(float)
    rows, cols = m.shape

    for i in range(rows):
        # Buscar el pivote mayor en columna i para evitar divisiones por cero
        max_row = i + np.argmax(np.abs(m[i:, i]))
        # Intercambiar filas
        m[[i, max_row]] = m[[max_row, i]] 
        # Si el pivote es cero o menor que la tolerancia, indicamos que no es unica la solucion
        if abs(m[i, i]) < tol:
            raise ValueError("El sistema no tiene solucion unica.")

        m[i] = m[i] / m[i, i]

        # Hacemos ceros en la columna i para todas las demás filas.
        for j in range(rows):
            if j != i:
                factor = m[j, i]
                m[j] = m[j] - factor * m[i]

    return m[:, -1]




import pathlib
from setuptools import setup, find_packages
HERE = pathlib.Path(__file__).parent


setup(
    name='SR23002UNO',
    version='1.0.2',
    author='David Enrique Sixco Ramos',
    author_email='sr23002@ues.edu.sv',
    description='Liberia para resolver ecuaciones lineales y no lineales',
    long_description=(HERE / "README.md").read_text(encoding='utf-8'),
    long_description_content_type='text/markdown',
    url='https://github.com/sr230002/CDA135-GT02-SR23002UNO',
    license='MIT',
    packages=['SR23002UNO'],
    include_package_data=True,
    install_requires=[
        'numpy',
    ],
)
